@@ -28,7 +28,7 @@ use constant EPP_XMLNS	=> 'urn:ietf:params:xml:ns:epp-1.0';
 use vars qw($Error $Code $Message);
 
 BEGIN {
-	our $VERSION = '0.06_01';
+	our $VERSION = '0.06_02';
 }
 
 # file-scoped lexicals
@@ -342,15 +342,18 @@ sub login {
 =head1 Availability checks
 
 The availability checks work similarly to L<Net::EPP::Simple> except
-that in list context they return an array with two elements.
+that in list context they return an array with up to three elements.
 The first element is the
 availability indicator as before (0 if provisioned, 1 if available,
-undef on error) and the second element is the abuse counter which shows
-how many more such checks you may run. This counter is only relevant
-for check_domain and will always be undef for the other check methods.
+undef on error). The second element is the abuse counter which shows
+how many more such checks you may run.
+The third element gives the reason for the lack of availability, if any.
+
+These two extra fields are only relevant for check_domain and will always
+be undef for the other check methods.
 
 	# List context
-	my ($avail, $left) = $epp->check_domain ("foo.uk");
+	my ($avail, $left, $reason) = $epp->check_domain ("foo.uk");
 	($avail) = $epp->check_contact ("ABC123");
 	($avail) = $epp->check_host ("ns0.foo.co.uk");
 
@@ -396,7 +399,11 @@ sub _check {
 	$count = $extra->getAttribute('abuse-limit') if defined $extra;
 	warn "Remaining checks = $count\n" if ($Debug and defined $count);
 
-	return ($avail, $count);
+	$extra = $response->getNode($spec[1], 'reason');
+	my $reason;
+	$reason = $extra->textContent if defined $extra;
+
+	return ($avail, $count, $reason);
 }
 
 =head1 Domain Renewal
